@@ -4,6 +4,12 @@ DEFAULT_GALLERY_TYPE = "default"
 GALLERY_TYPES = {}
 PAGE_SIZE = 10
 
+TRANSITIONS = (
+    ('fade', 'Fade'),
+    ('slide', 'Slide'),
+    ('show', 'Show')
+)
+
 def AddGalleryType(klass):
     if klass not in GALLERY_TYPES.values():
         GALLERY_TYPES[klass().name()] = klass
