@@ -221,6 +221,12 @@ class PicasaGallery:
             #Do not show anything if connection failed
             return []
     
+    def numberOfImages(self):
+        try:
+            picasaGallery = self.feed()
+            return len(picasaGallery.entry)
+        except:
+            return 0
 
     def getFirstImage(self):
         try:
